package {{$name}};

use strict;
use warnings;

our $VERSION = '0.001';

1;

=head1 NAME

{{$name}} - Module abstract

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 BUGS

Report any issues on the public bugtracker.

=head1 AUTHOR

{{$dist->authors->[0]}}

=head1 COPYRIGHT AND LICENSE

{{$dist->license->notice}}
=head1 SEE ALSO

